EnumRepr

Enum EnumRepr 

#[non_exhaustive]
pub enum EnumRepr { Flattened, ExternallyTagged, InternallyTagged { tag: &'static str, }, AdjacentlyTagged { tag: &'static str, content: &'static str, }, }
How enum variants are represented in the serialized format.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Flattened

Variant fields are flattened to the same level as other fields. Also used for #[facet(untagged)] enums where there’s no tag at all. Used by formats like TOML where all fields appear at one level. Example: {"name": "...", "host": "...", "port": 8080}



ExternallyTagged

Variant name is a key, variant content is nested under it. This is the default serde representation for enums. Example: {"name": "...", "Tcp": {"host": "...", "port": 8080}}



InternallyTagged

Tag field is inside the content, alongside variant fields. Used with #[facet(tag = "type")]. Example: {"type": "Tcp", "host": "...", "port": 8080}

Fields

tag: &'static str

The name of the tag field (e.g., “type”)



AdjacentlyTagged

Tag and content are adjacent fields at the same level. Used with #[facet(tag = "t", content = "c")]. Example: {"t": "Tcp", "c": {"host": "...", "port": 8080}}

Fields

tag: &'static str

The name of the tag field (e.g., “t”)

content: &'static str

The name of the content field (e.g., “c”)

Implementations

Source

impl EnumRepr

pub const fn from_shape(shape: &'static Shape) -> Self

Detect the enum representation from a Shape’s attributes.

Returns:

  • Flattened if #[facet(untagged)]
  • InternallyTagged if #[facet(tag = "...")] without content
  • AdjacentlyTagged if both #[facet(tag = "...", content = "...")]
  • ExternallyTagged if no attributes (the default enum representation)