VariantFormat

Enum VariantFormat 

#[non_exhaustive]
pub enum VariantFormat { Unit, NewtypeScalar { inner_shape: &'static Shape, }, NewtypeStruct { inner_shape: &'static Shape, }, NewtypeTuple { inner_shape: &'static Shape, arity: usize, }, NewtypeSequence { inner_shape: &'static Shape, }, NewtypeOther { inner_shape: &'static Shape, }, Tuple { arity: usize, }, Struct, }
Classification of an enum variant’s expected serialized format.

This is used by deserializers to determine how to parse untagged enum variants based on the YAML/JSON/etc. value type they encounter.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Unit

Unit variant: no fields, serializes as the variant name or nothing for untagged



NewtypeScalar

Newtype variant wrapping a scalar type (String, numbers, bool, etc.) Serializes as just the scalar value for untagged enums.

Fields

inner_shape: &'static Shape

The shape of the inner scalar type



NewtypeStruct

Newtype variant wrapping a struct Serializes as a mapping for untagged enums.

Fields

inner_shape: &'static Shape

The shape of the inner struct type



NewtypeTuple

Newtype variant wrapping a tuple struct/tuple Serializes as a sequence for untagged enums.

Fields

inner_shape: &'static Shape

The shape of the inner tuple type

arity: usize

Number of elements in the inner tuple



NewtypeSequence

Newtype variant wrapping a sequence type (Vec, Array, Slice, Set) Serializes as a sequence for untagged enums.

Fields

inner_shape: &'static Shape

The shape of the inner sequence type



NewtypeOther

Newtype variant wrapping another type (enum, map, etc.)

Fields

inner_shape: &'static Shape

The shape of the inner type



Tuple

Tuple variant with multiple fields Serializes as a sequence for untagged enums.

Fields

arity: usize

Number of fields in the tuple



Struct

Struct variant with named fields Serializes as a mapping for untagged enums.

Implementations

Source

impl VariantFormat

pub fn from_variant(variant: &'static Variant) -> Self

Classify a variant’s expected serialized format.

pub const fn expects_scalar(&self) -> bool

Returns true if this variant expects a scalar value in untagged format.

pub const fn expects_sequence(&self) -> bool

Returns true if this variant expects a sequence in untagged format.

pub const fn expects_mapping(&self) -> bool

Returns true if this variant expects a mapping in untagged format.

pub const fn is_unit(&self) -> bool

Returns true if this is a unit variant (no data).